@@ -40,8 +40,7 @@ str_before_last_dot <- function(string) {
     return(character())
   }
   checkmate::assert_character(string)
-  string %>%
-    tools::file_path_sans_ext() %T>% {
-      .[(string == .) & (str_elem(., 1) == ".")] <- ""
-    }
+  out <- tools::file_path_sans_ext(string)
+  out[(string == out) & (str_elem(out, 1) == ".")] <- ""
+  out
 }
