@@ -11,11 +11,12 @@
 #' string <- "\"abc\"67a\'dk\'f"
 #' cat(string)
 #' str_remove_quoted(string)
-#'
 #' @family removers
 #' @export
 str_remove_quoted <- function(string) {
-  if (is_l0_char(string)) return(character())
+  if (is_l0_char(string)) {
+    return(character())
+  }
   checkmate::assert_character(string)
   string <- str_replace_all(string, "(?:\".*?\")", "")
   string <- str_replace_all(string, "(?:\'.*?\')", "")
